@@ -1,4 +1,4 @@
-// $Id: commandids.h,v 1.10 1999/05/29 17:08:47 jsixt Exp $
+// $Id: commandids.h,v 1.16 2000/08/18 15:24:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -16,6 +16,7 @@
 #define ID_FILE_QUIT 8
 #define ID_FILE_COREFILE 9
 #define ID_FILE_GLOBAL_OPTIONS 10
+#define ID_FILE_PROG_SETTINGS 11
 
 #define ID_PROGRAM_RUN 20
 #define ID_PROGRAM_STEP 21
@@ -27,11 +28,14 @@
 #define ID_PROGRAM_RUN_AGAIN 27
 #define ID_PROGRAM_ATTACH 28
 #define ID_PROGRAM_DETACH 29
+#define ID_PROGRAM_KILL 30
+#define ID_PROGRAM_STEPI 31
+#define ID_PROGRAM_NEXTI 32
 
-#define ID_BRKPT_SET 30
-#define ID_BRKPT_TEMP 31
-#define ID_BRKPT_ENABLE 32
-#define ID_BRKPT_LIST 35
+#define ID_BRKPT_SET 40
+#define ID_BRKPT_TEMP 41
+#define ID_BRKPT_ENABLE 42
+#define ID_BRKPT_LIST 45
 
 #define ID_EDIT_COPY 50
 #define ID_EDIT_PASTE 51
@@ -42,6 +46,14 @@
 #define ID_VIEW_TOOLBAR 60
 #define ID_VIEW_STATUSBAR 61
 #define ID_VIEW_FINDDLG 62
+#define ID_VIEW_SOURCE 63
+#define ID_VIEW_STACK 64
+#define ID_VIEW_LOCALS 65
+#define ID_VIEW_WATCHES 66
+#define ID_VIEW_REGISTERS 67
+#define ID_VIEW_THREADS 68
+#define ID_VIEW_OUTPUT 69
+#define ID_VIEW_MEMORY 70
 
 #define ID_HELP_ABOUT 100
 #define ID_HELP_HELP  101
