@@ -1,4 +1,4 @@
-// $Id: dbgdriver.h,v 1.16 2000/08/18 19:22:48 jsixt Exp $
+// $Id: dbgdriver.h,v 1.16.2.1 2002/01/01 17:01:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -355,7 +355,7 @@ public:
     /**
      * Parses the output as an array of QChars.
      */
-    virtual VarTree* parseQCharArray(const char* output, bool wantErrorValue) = 0;
+    virtual VarTree* parseQCharArray(const char* output, bool wantErrorValue, bool qt3like) = 0;
 
     /**
      * Parses a back-trace (the output of the DCbt command).
