@@ -1,4 +1,4 @@
-// $Id: dbgmainwnd.cpp,v 1.49 2001/07/17 20:31:48 jsixt Exp $
+// $Id: dbgmainwnd.cpp,v 1.50.2.1 2001/12/29 20:12:16 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -8,6 +8,7 @@
 #include <klocale.h>			/* i18n */
 #include <kmenubar.h>
 #include <kconfig.h>
+#include <kstatusbar.h>
 #endif
 #include <kiconloader.h>
 #include <kstdaccel.h>
@@ -414,10 +415,16 @@ void DebuggerMainWnd::menuCallback(int item)
 	kapp->quit();
 	break;
     case ID_VIEW_TOOLBAR:
-	enableToolBar();
+	if (toolBar()->isVisible())
+	    toolBar()->hide();
+	else
+	    toolBar()->show();
 	break;
     case ID_VIEW_STATUSBAR:
-	enableStatusBar();
+	if (statusBar()->isVisible())
+	    statusBar()->hide();
+	else
+	    statusBar()->show();
 	break;
     case ID_PROGRAM_UNTIL:
 	if (m_debugger != 0)
