@@ -1,4 +1,4 @@
-// $Id: debugger.cpp,v 1.105 2001/06/23 19:24:06 jsixt Exp $
+// $Id: debugger.cpp,v 1.106.2.1 2002/01/01 17:01:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -1437,7 +1437,7 @@ void KDebugger::handlePrintStruct(CmdQueueItem* cmd, const char* output)
     if (cmd->m_cmd != DCprintQStringStruct) {
 	partExpr = parseExpr(output, false);
     } else {
-	partExpr = m_d->parseQCharArray(output, false);
+	partExpr = m_d->parseQCharArray(output, false, m_typeTable->qCharIsShort());
     }
     bool errorValue =
 	partExpr == 0 ||
@@ -1447,7 +1447,7 @@ void KDebugger::handlePrintStruct(CmdQueueItem* cmd, const char* output)
     QString partValue;
     if (errorValue)
     {
-	partValue = "???";
+	partValue = "?""?""?";	// 2 question marks in a row would be a trigraph
     } else {
 	partValue = partExpr->m_value;
     }
@@ -1463,7 +1463,8 @@ void KDebugger::handlePrintStruct(CmdQueueItem* cmd, const char* output)
      * 
      * If the expression we just evaluated was a guard expression, and it
      * resulted in an error, we must not evaluate the real expression, but
-     * go on to the next index. (We must still add the ??? to the value).
+     * go on to the next index. (We must still add the question marks to
+     * the value).
      * 
      * Next, if this was the length expression, we still have not seen the
      * real expression, but the length of a QString.
@@ -1472,7 +1473,7 @@ void KDebugger::handlePrintStruct(CmdQueueItem* cmd, const char* output)
 
     if (errorValue || !var->m_exprIndexUseGuard)
     {
-	// add current partValue (which might be ???)
+	// add current partValue (which might be the question marks)
 #if QT_VERSION < 200
 	var->m_partialValue.detach();
 #endif
@@ -1858,7 +1859,7 @@ void KDebugger::slotValuePopup(const QString& expr)
 	    tip += "[...]";
 	    break;
 	default:
-	    tip += "???";
+	    tip += "?""?""?";	// 2 question marks in a row would be a trigraph
 	    break;
 	}
     }
