@@ -1,4 +1,4 @@
-// $Id: exprwnd.cpp,v 1.19 2000/01/06 16:46:15 jsixt Exp $
+// $Id: exprwnd.cpp,v 1.19.2.3 2002/01/19 21:43:07 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -81,7 +81,22 @@ QString VarTree::computeExpr() const
     }
     switch (par->m_varKind) {
     case VKarray:
-	result = "(" + parentExpr + ")" + getText();
+	{
+	    QString index = getText();
+	    int i = 1;
+	    // skip past the index
+	    while (index[i].isDigit())
+		i++;
+	    /*
+	     * Some array indices are actually ranges due to repeated array
+	     * values. We use the first index in these cases.
+	     */
+	    if (index[i] != ']') {
+		// remove second index
+		index.remove(i, index.length()-i-1);
+	    }
+	    result = "(" + parentExpr + ")" + index;
+	}
 	break;
     case VKstruct:
 	result = "(" + parentExpr + ")." + getText();
@@ -230,7 +245,6 @@ ExprWnd::ExprWnd(QWidget* parent, const char* name) :
 	maxValueWidth(0)
 {
     setNumCols(2);
-    clearTableFlags(Tbl_clipCellPainting);
     
     connect(this, SIGNAL(expanded(int)), SLOT(slotExpandOrCollapse(int)));
     connect(this, SIGNAL(collapsed(int)), SLOT(slotExpandOrCollapse(int)));
@@ -449,8 +463,8 @@ void ExprWnd::updateStructValue(VarTree* display)
     if (display->updateValue(display->m_partialValue)) {
 	int i = itemRow(display);
 	if (i >= 0) {
-	    updateCell(i, 1, true);
 	    updateValuesWidth();
+	    updateCell(i, 1, true);
 	}
     }
     // reset the value
@@ -633,7 +647,7 @@ void ExprWnd::paintCell(QPainter* painter, int row, int col)
     }
 }
 
-int ExprWnd::cellWidth(int col)
+int ExprWnd::cellWidth(int col) const
 {
     if (col == 0) {
 	return KTreeView::cellWidth(col);
