@@ -1,4 +1,4 @@
-// $Id: exprwnd.h,v 1.13 1999/12/18 13:39:12 jsixt Exp $
+// $Id: exprwnd.h,v 1.13.2.1 2001/12/28 21:10:28 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -85,7 +85,7 @@ protected:
     bool updateExprRec(VarTree* display, VarTree* newValues);
     void replaceChildren(VarTree* display, VarTree* newValues);
     virtual void paintCell(QPainter* painter, int row, int col);
-    virtual int cellWidth(int col);
+    virtual int cellWidth(int col) const;
     void updateValuesWidth();
     static bool getMaxValueWidth(KTreeViewItem* item, void* user);
     void collectUnknownTypes(VarTree* item);
