@@ -1,5 +1,5 @@
 /*
- * $Id: ktreeview.cpp,v 1.12 2000/11/11 11:12:29 jsixt Exp $
+ * $Id: ktreeview.cpp,v 1.13.2.2 2001/12/29 20:12:16 jsixt Exp $
  *
  * KTreeView implementation
  * 
@@ -339,39 +339,21 @@ void KTreeViewItem::paintExpandButton(QPainter* p, int indent, int cellHeight,
 
 // paint the highlight 
 void KTreeViewItem::paintHighlight(QPainter* p, int indent, const QColorGroup& colorGroup,
-				   bool hasFocus, GUIStyle style) const
+				   bool hasFocus) const
 {
     QColor fc;
-    if (style == WindowsStyle)
-	fc = darkBlue;			/* hardcoded in Qt */
-    else
-	fc = colorGroup.text();
+    fc = colorGroup.text();
     QRect textRect = textBoundingRect(indent);
     int t,l,b,r;
     textRect.coords(&l, &t, &r, &b);
     QRect outerRect;
     outerRect.setCoords(l - 2, t - 2, r + 2, b + 2);
-    if (style == WindowsStyle) {	/* Windows style highlight */
-	if (hasFocus) {
-	    p->fillRect(textRect, fc);	/* highlight background */
-	    textRect.setCoords(l - 1, t - 1, r + 1, b + 1);
-	    p->setPen(QPen(yellow, 0, DotLine));
-	    p->setBackgroundColor(fc);
-	    p->setBackgroundMode(OpaqueMode);
-	    p->drawRect(textRect);
-	    p->setPen(fc);
-	    p->drawRect(outerRect);
-	} else {
-	    p->fillRect(outerRect, fc);	/* highlight background */
-	}
-    } else {				/* Motif style highlight */
-	if (hasFocus) {
-	    p->fillRect(textRect, fc);	/* highlight background */
-	    p->setPen(fc);
-	    p->drawRect(outerRect);
-	} else {
-	    p->fillRect(outerRect, fc);	/* highlight background */
-	}
+    if (hasFocus) {
+	p->fillRect(textRect, fc);	/* highlight background */
+	p->setPen(fc);
+	p->drawRect(outerRect);
+    } else {
+	p->fillRect(outerRect, fc);	/* highlight background */
     }
 }
 
@@ -384,8 +366,7 @@ void KTreeViewItem::paintText(QPainter* p, int indent, int cellHeight,
 	p->fontMetrics().ascent();
 
     if (highlighted) {
-	paintHighlight(p, indent, cg,
-		       owner->hasFocus(), owner->style());
+	paintHighlight(p, indent, cg, owner->hasFocus());
 	p->setPen(cg.base());
 	p->setBackgroundColor(cg.text());
     }
@@ -593,7 +574,7 @@ int KTreeViewItem::width(int indent, const QFontMetrics& fm) const
 KTreeView::KTreeView(QWidget *parent,
 		     const char *name,
 		     WFlags f) :
-	QTableView(parent, name, f),
+	TableView(parent, name, f),
 	clearing(false),
 	current(-1),
 	drawExpandButton(true),
@@ -607,28 +588,10 @@ KTreeView::KTreeView(QWidget *parent,
 	visibleItems(0),
 	rubberband_mode(false)
 {
-    initMetaObject();
-    setCellHeight(0);
-    setCellWidth(0);
     setNumRows(0);
     setNumCols(1);
-    setTableFlags(Tbl_autoScrollBars | Tbl_clipCellPainting | Tbl_snapToVGrid);
-    clearTableFlags(Tbl_scrollLastVCell | Tbl_scrollLastHCell | Tbl_snapToVGrid);
-    switch(style()) {
-    case WindowsStyle:
-    case MotifStyle:
-	setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
-	setBackgroundColor(colorGroup().base());
-	break;
-    default:
-	setFrameStyle(QFrame::Panel | QFrame::Plain);
-	setLineWidth(1);
-    }
-#if QT_VESION < 200
-    setFocusPolicy(StrongFocus);
-#else
-    setFocusPolicy(WheelFocus);
-#endif
+    setBackgroundColor(colorGroup().base());
+
     treeRoot = new KTreeViewItem;
     treeRoot->setExpanded(true);
     treeRoot->owner = this;
@@ -690,30 +653,6 @@ void KTreeView::appendChildItem(KTreeViewItem* newItem, const KPath& thePath)
     appendChildItem(parentItem, newItem);
 }
                                  
-// indicates whether horizontal scrollbar appears only when needed
-bool KTreeView::autoBottomScrollBar() const
-{
-  return testTableFlags(Tbl_autoHScrollBar);
-}
-
-// indicates whether vertical scrollbar appears only when needed
-bool KTreeView::autoScrollBar() const
-{
-  return testTableFlags(Tbl_autoVScrollBar);
-}
-
-// indicates whether display updates automatically on changes
-bool KTreeView::autoUpdate() const
-{
-  return QTableView::autoUpdate();
-}
-
-// indicates whether horizontal scrollbar is present
-bool KTreeView::bottomScrollBar() const
-{
-  return testTableFlags(Tbl_hScrollBar);
-}
-
 // translate mouse coord to cell coord
 QPoint KTreeView::cellCoords(int row, const QPoint& widgetCoord)
 {
@@ -957,7 +896,7 @@ bool KTreeView::insertItem(KTreeViewItem* newItem,
  * returns pointer to KTreeViewItem at the specifed row or 0 if row is out
  * of limits.
  */
-KTreeViewItem* KTreeView::itemAt(int row)
+KTreeViewItem* KTreeView::itemAt(int row) const
 {
     if (row < 0 || row >= numRows()) {
 	return 0;
@@ -1086,12 +1025,6 @@ void KTreeView::removeItem(const KPath& thePath)
     }
 }
 
-// indicates whether vertical scrollbar is present
-bool KTreeView::scrollBar() const
-{
-  return testTableFlags(Tbl_vScrollBar);
-}
-
 void KTreeView::scrollVisible(KTreeViewItem* item, bool children)
 {
     if (item == 0)
@@ -1134,19 +1067,6 @@ void KTreeView::scrollVisible(KTreeViewItem* item, bool children)
     }
 }
 
-// enables/disables auto update of display
-void KTreeView::setAutoUpdate(bool enable)
-{
-  QTableView::setAutoUpdate(enable);
-}
-
-// enables/disables horizontal scrollbar
-void KTreeView::setBottomScrollBar(bool enable)
-{
-  enable ? setTableFlags(Tbl_hScrollBar) :
-    clearTableFlags(Tbl_hScrollBar);
-}
-
 // sets the current item and hightlights it, emitting signals
 void KTreeView::setCurrentItem(int row)
 {
@@ -1215,13 +1135,6 @@ void KTreeView::setMoveCurrentToSibling(bool m)
     moveCurrentToSibling = m;
 }
 
-// enables/disables vertical scrollbar
-void KTreeView::setScrollBar(bool enable)
-{
-  enable ? setTableFlags(Tbl_vScrollBar) :
-    clearTableFlags(Tbl_vScrollBar);
-}
-
 // enables/disables display of item text (keys)
 void KTreeView::setShowItemText(bool enable)
 {
@@ -1236,13 +1149,6 @@ void KTreeView::setShowItemText(bool enable)
 	repaint();
 }
 
-// indicates whether vertical scrolling is by pixel or row
-void KTreeView::setSmoothScrolling(bool enable)
-{
-  enable ? setTableFlags(Tbl_smoothVScrolling) :
-    clearTableFlags(Tbl_smoothVScrolling);
-}
-
 // enables/disables tree branch drawing
 void KTreeView::setTreeDrawing(bool enable)
 {
@@ -1263,12 +1169,6 @@ bool KTreeView::showItemText() const
   return showText;
 }
 
-// indicates whether scrolling is by pixel or row
-bool KTreeView::smoothScrolling() const
-{
-  return testTableFlags(Tbl_smoothVScrolling);
-}
-
 // indents the item at the given index, splitting the tree into
 // a new branch
 void KTreeView::split(int index)
@@ -1345,14 +1245,14 @@ void KTreeView::appendChildItem(KTreeViewItem* theParent,
 }
 
 // returns the height of the cell(row) at the specified row (index)
-int KTreeView::cellHeight(int row)
+int KTreeView::cellHeight(int row) const
 {
   return itemAt(row)->height(fontMetrics());
 }
 
 // returns the width of the cells. Note: this is mostly for derived classes
 // which have more than 1 column
-int KTreeView::cellWidth(int /*col*/)
+int KTreeView::cellWidth(int /*col*/) const
 {
   return maxItemWidth;
 }
@@ -2096,7 +1996,7 @@ void KTreeView::takeItem(KTreeViewItem* item)
 }
 
 // visits each item, calculates the maximum width  
-// and updates QTableView
+// and updates TableView
 void KTreeView::updateCellWidth()
 {
     // make cells at least 1 pixel wide to avoid singularities (division by zero)
