@@ -1,4 +1,4 @@
-// $Id: main.cpp,v 1.19 2000/11/05 17:04:35 jsixt Exp $
+// $Id: main.cpp,v 1.21.2.1 2001/12/29 20:12:16 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -12,7 +12,8 @@
 #include <kstddirs.h>
 #include <kcmdlineargs.h> 
 #include <kaboutdata.h>
-#include <khelpmenu.h> 
+#include <khelpmenu.h>
+#include <kpopupmenu.h>
 #else // QT_VERSION < 200
 #include <kmsgbox.h>
 #endif
@@ -53,7 +54,7 @@ int main(int argc, char** argv)
 			 VERSION,
 			 description,
 			 KAboutData::License_GPL, 
-			 "(c) 1998-2000 Johannes Sixt",
+			 "(c) 1998-2001 Johannes Sixt",
 			 0,		/* any text */
 			 "http://members.nextra.at/johsixt/kdbg.html",
 			 "Johannes.Sixt@telecom.at");
@@ -97,7 +98,7 @@ int main(int argc, char** argv)
     // session management
     bool restored = false;
     if (app.isRestored()) {
-	if (KTMainWindow::canBeRestored(1)) {
+	if (KMainWindow::canBeRestored(1)) {
 	    debugger.restore(1);
 	    restored = true;
 	}
