@@ -1,4 +1,4 @@
-// $Id: memwindow.h,v 1.5 2000/08/18 14:16:22 jsixt Exp $
+// $Id: memwindow.h,v 1.5.2.1 2001/12/14 21:05:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -12,6 +12,7 @@
 #include <qlayout.h>
 #include <qdict.h>
 #include <qlist.h>
+#include <qmap.h>
 
 class KDebugger;
 class KSimpleConfig;
@@ -29,7 +30,10 @@ public:
 protected:
     KDebugger* m_debugger;
     QComboBox m_expression;
+
     QListView m_memory;
+    QMap<QString,QString> m_old_memory;
+
     QVBoxLayout m_layout;
 
     unsigned m_format;
