@@ -1,10 +1,11 @@
-// $Id: pgmargs.cpp,v 1.14 2000/11/11 11:12:29 jsixt Exp $
+// $Id: pgmargs.cpp,v 1.16 2001/04/16 17:24:44 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
 
 #include "pgmargs.h"
 #include <kapp.h>
+#include <kfiledialog.h>
 #if QT_VERSION >= 200
 #include <klocale.h>			/* i18n */
 #endif
@@ -17,6 +18,7 @@ PgmArgs::PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars) :
 	m_programArgs(this, "args"),
 	m_wdLabel(this, "wd_label"),
 	m_wd(this, "wd"),
+	m_wdBrowse(this, "wd_browse"),
 	m_envLabel(this, "env_label"),
 	m_envVar(this, "env_var"),
 	m_envList(this, "env_list"),
@@ -26,7 +28,8 @@ PgmArgs::PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars) :
 	m_buttonDelete(this, "delete"),
 	m_layout(this, 8),
 	m_edits(8),
-	m_buttons(8)
+	m_buttons(8),
+	m_wdEdit(0)
 {
     m_envVars.setAutoDelete(false);
 
@@ -57,6 +60,11 @@ PgmArgs::PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars) :
     m_wdLabel.setMinimumSize(s);
     int btnSpace = s.height();
 
+    m_wdBrowse.setText("...");
+    s = m_wdBrowse.sizeHint();
+    m_wdBrowse.setMinimumSize(s);
+    connect(&m_wdBrowse, SIGNAL(clicked()), SLOT(browseWd()));
+
     s = m_wd.sizeHint();
     m_wd.setMinimumSize(s);
     m_wd.setMaxLength(10000);
@@ -103,7 +111,7 @@ PgmArgs::PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars) :
     m_edits.addWidget(&m_label);
     m_edits.addWidget(&m_programArgs);
     m_edits.addWidget(&m_wdLabel);
-    m_edits.addWidget(&m_wd);
+    m_edits.addLayout(&m_wdEdit);
     m_edits.addWidget(&m_envLabel);
     m_edits.addWidget(&m_envVar);
     m_edits.addWidget(&m_envList, 10);
@@ -113,6 +121,8 @@ PgmArgs::PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars) :
     m_buttons.addWidget(&m_buttonModify);
     m_buttons.addWidget(&m_buttonDelete);
     m_buttons.addStretch(10);
+    m_wdEdit.addWidget(&m_wd, 10);
+    m_wdEdit.addWidget(&m_wdBrowse);
 
     m_layout.activate();
 
@@ -235,4 +245,17 @@ void PgmArgs::accept()
     QDialog::accept();
 }
 
+void PgmArgs::browseWd()
+{
+    // browse for the working directory
+#if QT_VERSION < 200
+    QString newDir = KDirDialog::getDirectory(wd(), this);
+#else
+    QString newDir = KFileDialog::getExistingDirectory(wd(), this);
+#endif
+    if (!newDir.isEmpty()) {
+	setWd(newDir);
+    }
+}
+
 #include "pgmargs.moc"
