@@ -1,4 +1,4 @@
-// $Id: sourcewnd.cpp,v 1.7 2000/06/10 19:33:46 jsixt Exp $
+// $Id: sourcewnd.cpp,v 1.7.2.4 2002/01/20 17:37:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -54,18 +54,28 @@ SourceWindow::~SourceWindow()
 {
 }
 
-void SourceWindow::loadFile()
+bool SourceWindow::loadFile()
 {
     // first we load the code into KTextView::m_texts
     QFile f(m_fileName);
-    if (f.open(IO_ReadOnly)) {
-	QTextStream t(&f);
-	QString s;
-	while (!t.eof()) {
-	    s = t.readLine();
-	    insertLine(s);
-	}
-	f.close();
+    if (!f.open(IO_ReadOnly)) {
+	return false;
+    }
+
+    bool upd = autoUpdate();
+    setAutoUpdate(false);
+
+    QTextStream t(&f);
+    QString s;
+    while (!t.eof()) {
+	s = t.readLine();
+	insertLine(s);
+    }
+    f.close();
+
+    setAutoUpdate(upd);
+    if (upd) {
+	updateTableSize();
     }
 
     // then we copy it into our own m_sourceCode
@@ -77,6 +87,8 @@ void SourceWindow::loadFile()
 	m_rowToLine[i] = i;
 	m_lineItems[i] = 0;
     }
+
+    return true;
 }
 
 void SourceWindow::reloadFile()
@@ -122,11 +134,6 @@ void SourceWindow::reloadFile()
 	// remove the excessive lines
 	m_texts.setSize(lineNo);
 	m_lineItems.setSize(lineNo);
-	// if the cursor is in the deleted lines, move it to the last line
-	if (m_curRow >= lineNo) {
-	    m_curRow = -1;		/* at this point don't have an active row */
-	    activateLine(lineNo-1);	/* now we have */
-	}
     }
     f.close();
 
@@ -138,8 +145,15 @@ void SourceWindow::reloadFile()
 
     setAutoUpdate(autoU);
     if (autoU && isVisible()) {
+	updateTableSize();
 	repaint();
     }
+
+    // if the cursor is in the deleted lines, move it to the last line
+    if (m_curRow >= m_texts.size()) {
+	m_curRow = -1;			/* at this point don't have an active row */
+	activateLine(m_texts.size()-1);	/* now we have */
+    }
 }
 
 void SourceWindow::scrollTo(int lineNo, const DbgAddr& address)
@@ -179,7 +193,7 @@ int SourceWindow::textCol() const
     return 2;
 }
 
-int SourceWindow::cellWidth(int col)
+int SourceWindow::cellWidth(int col) const
 {
     if (col == 0) {
 	return 15;
@@ -573,7 +587,7 @@ void SourceWindow::disassembled(int lineNo, const QList<DisassembledCode>& disas
 
 int SourceWindow::rowToLine(int row, int* sourceRow)
 {
-    int line = m_rowToLine[row];
+    int line = row >= 0  ?  m_rowToLine[row]  :  -1;
     if (sourceRow != 0) {
 	// search back until we hit the first entry with the current line number
 	while (row > 0 && m_rowToLine[row-1] == line)
@@ -690,8 +704,10 @@ void SourceWindow::expandRow(int row)
     emit expanded(line);		/* must set PC */
 
     setAutoUpdate(autoU);
-    if (autoU && isVisible())
+    if (autoU && isVisible()) {
+	updateTableSize();
 	update();
+    }
 }
 
 void SourceWindow::collapseRow(int row)
@@ -717,8 +733,10 @@ void SourceWindow::collapseRow(int row)
     emit collapsed(line);
 
     setAutoUpdate(autoU);
-    if (autoU && isVisible())
+    if (autoU && isVisible()) {
+	updateTableSize();
 	update();
+    }
 }
 
 void SourceWindow::activeLine(int& line, DbgAddr& address)
