@@ -1,4 +1,4 @@
-// $Id: sourcewnd.h,v 1.4 2000/04/16 19:03:11 jsixt Exp $
+// $Id: sourcewnd.h,v 1.4.2.2 2001/12/28 21:10:28 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -21,7 +21,7 @@ public:
     SourceWindow(const char* fileName, QWidget* parent, const char* name);
     ~SourceWindow();
     
-    void loadFile();
+    bool loadFile();
     void reloadFile();
     bool fileNameMatches(const QString& other);
     void scrollTo(int lineNo, const DbgAddr& address);
@@ -51,7 +51,7 @@ public:
 
 protected:
     virtual int textCol() const;
-    virtual int cellWidth(int col);
+    virtual int cellWidth(int col) const;
     virtual void paintCell(QPainter* p, int row, int col);
     virtual void mousePressEvent(QMouseEvent* ev);
     virtual void keyPressEvent(QKeyEvent* ev);
