@@ -1,4 +1,4 @@
-// $Id: typetable.cpp,v 1.8 1999/09/28 17:43:45 jsixt Exp $
+// $Id: typetable.cpp,v 1.8.2.1 2002/01/01 17:01:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -233,7 +233,8 @@ TypeInfo::~TypeInfo()
 
 
 ProgramTypeTable::ProgramTypeTable() :
-	m_parseQt2QStrings(false)
+	m_parseQt2QStrings(false),
+	m_QCharIsShort(false)
 {
     m_types.setAutoDelete(false);	/* paranoia */
     m_aliasDict.setAutoDelete(false);	/* paranoia */
@@ -255,6 +256,9 @@ void ProgramTypeTable::loadTypeTable(TypeTable* table)
     if (!m_parseQt2QStrings) {
 	m_parseQt2QStrings = table->isEnabledBuiltin("QString::Data");
     }
+    if (!m_QCharIsShort) {
+	m_QCharIsShort = table->isEnabledBuiltin("QCharIsShort");
+    }
 }
 
 TypeInfo* ProgramTypeTable::lookup(const char* type)
