@@ -1,4 +1,4 @@
-// $Id: typetable.h,v 1.5 1999/04/05 09:09:52 jsixt Exp $
+// $Id: typetable.h,v 1.5.2.1 2002/01/01 17:01:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -150,8 +150,14 @@ public:
      */
     bool parseQt2QStrings() const { return m_parseQt2QStrings; }
 
+    /**
+     * Tells whether QChar are defined like in Qt3.
+     */
+    bool qCharIsShort() const { return m_QCharIsShort; }
+
 protected:
     QDict<TypeInfo> m_types;
     QDict<TypeInfo> m_aliasDict;
     bool m_parseQt2QStrings;
+    bool m_QCharIsShort;
 };
